@@ -66,8 +66,8 @@ class Domoticz(IPlugin):
 
 	def devices(self, jsonInput):
 		bodies = ""
-		if jsonInput['outcome']['entities']['location']['body'] :
-			location = jsonInput['outcome']['entities']['location']['body']
+		if jsonInput['outcome']['entities']['location']['value'] :
+			location = jsonInput['outcome']['entities']['location']['value']
 		else:
 			location = "pas de lieu"
 			bodies = ""
